---
hide_toc: true
...

# About this site

This web site was generated with the Elstir static site generator, a fork of [MkDocs](https://Mkdocs.org) which uses [Pandoc](https://Pandoc.org) in the backend. The theme is heavily adapted from [Bootswatch](https://bootswatch.com/). Additional sources of inspiration for the layout of this site include [Numba](http://numba.pydata.org/).

## Disclaimer

